import React, { useEffect, useState, useCallback, useRef } from 'react';
import { Grid, GridColumn as Column, getSelectedState } from '@progress/kendo-react-grid';
import Backdrop from '@mui/material/Backdrop';
import CircularProgress from '@mui/material/CircularProgress';
import { getter } from '@progress/kendo-react-common';
import { filterBy } from "@progress/kendo-data-query";
import { orderBy } from "@progress/kendo-data-query";
import { auto } from '@popperjs/core';
import { ColumnMenu } from '../Common/ColumnMenu';
import { FirstName } from '../../stories/TextField.stories';


const DATA_ITEM_KEY = 'Id';
const SELECTED_FIELD = 'selected';
const idGetter = getter(DATA_ITEM_KEY);

const initialSort = [
  {
    field: "0",
    dir: "desc",
  },
];


export const Kendo_Grid =(props) => {

  // var api_url = config.url.API_URL;

  const initialDataState = {
    skip: 0,
    take: 100
  };

  const [isLoading, setIsLoading] = useState(false);

  const [Data1, setData] = useState([]);

  const [page, setPage] = React.useState(initialDataState);
  const [filter, setFilter] = useState();
  const [sort, setSort] = useState();

  useEffect(() => {
    if (props.data != null) {
      setData(props.data)
    }
  
}, []);

  /////Old updated functionality
  const [checkedState, setCheckedState] = useState(
    new Array(Data1.length).fill(false)
  );

  const [selectedState, setSelectedState] = useState({});

  const onSelectionChange = useCallback(event => {
    const newSelectedState = getSelectedState({
      event,
      selectedState: selectedState,
      dataItemKey: DATA_ITEM_KEY
    });
   // const {event,selectedState} =newSelectedState
    props.callBack(newSelectedState)
    setSelectedState(newSelectedState);
    
  }, [selectedState]);

  const onHeaderSelectionChange = useCallback(event => {
    const checkboxElement = event.syntheticEvent.target;
    const checked = checkboxElement.checked;
    const newSelectedState = {};
    event.dataItems.forEach(item => {
      newSelectedState[idGetter(item)] = checked;
    });
    props.callBack(newSelectedState)
    setSelectedState(newSelectedState);
  }, []);

  const CustomLinkCell = (props) => {  // custom cell for Detail 
    return (
        <td>
            <a href={`#`} onClick={() => alert("Custom Link Cell")} style={{ color: "#3377BB" }}>
                {props.dataItem.LAST_NAME}
            </a>
        </td>
    )
}

  async function pageChange(event) {
    props.callBack(event);
    setPage(event.page);


    setIsLoading(false);
  };

 


  return (
    <>
      <Backdrop
        sx={{ color: '#fff', zIndex: (theme) => theme.zIndex.drawer + 1 }}
        open={isLoading}
      >
        <CircularProgress color="inherit" />
      </Backdrop>
      <Grid style={{
        height: '90%'
      }}
        reorderable={true}
        fixedScroll={true}
        filter={filter}
        onFilterChange={(e) => setFilter(e.filter)
        }
        pageable={true}
        skip={page.skip}
        take={page.take}
        total={props.total}
        {...Data1}
        sortable={true}
        onSortChange={(e) => {
          setSort(e.sort);
        }
        }
        onPageChange={pageChange}

        data={filterBy(Data1.map(item => ({
          ...item,
          [SELECTED_FIELD]: selectedState[idGetter(item)]
        })), filter)}

        dataItemKey={DATA_ITEM_KEY} selectedField={SELECTED_FIELD} selectable={{
          enabled: false,
          drag: false,
          cell: false,
          mode: 'multiple'
        }} onSelectionChange={onSelectionChange} onHeaderSelectionChange={onHeaderSelectionChange}
      >
        {props.stateColumns.map(
          (column) =>
            column.show && (
              column.checkBox ?
                <Column field={SELECTED_FIELD} headerSelectionValue={Data1.findIndex(item => !selectedState[idGetter(item)]) === -1} />
                :
                column.customCell ?
                <Column field={column.field} title={column.title} columnMenu={ColumnMenu} cell={CustomLinkCell} />
                :
                <Column field={column.field} title={column.title} width={auto} columnMenu={ColumnMenu} />
            )
        )}
      </Grid>
    
    </>

  );


}

// export default Kendo_Grid;